#!/usr/bin/env python
''' highscores.py
    for storing high score data
'''

import pygame
from pygame.locals import *

class highscores():
    def __init__(self):
        self.gamefont = pygame.font.SysFont(None, 48)
        self.scores = []
        f = open('scores','r')
        for line in f:
            self.scores.append(int(line))
        f.close()
        self.scores = sorted(self.scores, reverse=True)
        self.lastHighScore = -1
        self.scoreSurfaces = []
        self.title = self.gamefont.render("HIGH SCORES",False,(255,255,255))
        self.note = self.gamefont.render("PRESS ANY KEY TO EXIT",False,(255,255,255))
        self.updateScores(-1)
    
    def updateScores(self, score):
        ''' updates scores with a new score
            returns True if score is a new high score
            returns False otherwise
        '''
        self.scores.append(score)
        self.lastHighScore = score
        self.scores = sorted(self.scores, reverse=True)
        self.scores = self.scores[:10]
        f = open('scores','w')
        for s in self.scores:
            f.write(str(s)+'\n')
        f.flush()
        f.close()
        self.updateScoreSurfs()
        for item in self.scores:
            if item == score:
                return True
        return False
    
    def updateScoreSurfs(self):
        ''' updates score surfaces '''
        self.scoreSurfaces = []
        for s in self.scores:
            if s == self.lastHighScore:
                self.scoreSurfaces.append(self.gamefont.render(str(s),
                                                               False,
                                                               (255,0,0)))
            else:
                self.scoreSurfaces.append(self.gamefont.render(str(s),
                                                               False,
                                                               (255,255,255)))
    
    def render(self, screen):
        screen.fill((0,0,0))
        y = 20
        x = 350
        screen.blit(self.title,(x-75,y))
        y += 45
        for s in self.scoreSurfaces:
            screen.blit(s,(x,y))
            y += 45
        screen.blit(self.note,(200,y))
    
    def keyHandler(self, event):
        pygame.event.post(pygame.event.Event(USEREVENT, uetype="exitgame"))