#!/usr/bin/env python
''' menu.py
    This is a generic menu class
'''

import pygame
from pygame.locals import *

class menu():
    ''' Generic Menu Class '''
    def __init__(self, menutitle, menuitems, menuactions, imagedir="sprites/"):
        ''' pass it a list of menuitems and it will load the graphics
            with the same name as the text being supplied
            Underscores preferred in file names and menu names
        '''
        self.menutitle = pygame.image.load(imagedir+menutitle+".png")
        self.menuitems = []
        for item in menuitems:
            self.menuitems.append(pygame.image.load(imagedir+item+".png"))
        self.selected = 0
        self.menusurface = pygame.Surface((400,len(self.menuitems) * 100))
        self.menuactions = menuactions
        self.maintitle = pygame.image.load(imagedir+"main_title_item.png")
    
    def selectNext(self):
        ''' set index to next menu item '''
        if(self.selected + 1 >= len(self.menuitems)):
            self.selected = 0
        else:
            self.selected += 1
    
    def selectPrevious(self):
        ''' set index to previous menu item '''
        if(self.selected - 1 < 0):
            self.selected = len(self.menuitems) - 1
        else:
            self.selected -= 1
    
    def renderMenu(self, screen):
        ''' Render the menu to the surface '''
        self.menusurface.fill((0,0,0))
        self.menusurface.blit(self.menutitle,(0,0))
        y = 0
        for item in self.menuitems:
            self.menusurface.blit(item,(50,y*50+100))
            y += 1
        # Draw selected item bigger
        self.menusurface.blit(pygame.transform.smoothscale(self.menuitems[self.selected],
                                                           (300,75)),
                              (0,self.selected*50-15+100))
        screen.blit(self.maintitle, (200,0))
        screen.blit(self.menusurface,(200,200))
    
    def keyHandler(self, event):
        ''' handles keypresses '''
        if event.key == K_UP:
            self.selectPrevious()
        if event.key == K_DOWN:
            self.selectNext()
        if event.key == K_RETURN:
            self.menuactions[self.selected]()
