#!/usr/bin/env python
''' map module for Get Out '''

import pygame
from pygame.locals import *
import numpy
from tileset import *
import random

class themap():
    ''' map class for Get Out '''
    def __init__(self, tset, mapsize=(25,19)):
        self.px = 12
        self.py = 10
        self.mapindex()
        self.tset = tset
        self.mapsize = mapsize
        self.genmap(mapsize)
        self.mapview = [0,0,25,19] # view window 25x19
    
    def genmap(self, mapsize):
        ''' Generates the base map for Get Out '''
        self.mapsize = mapsize
        self.gamemap = numpy.zeros(mapsize)
        random.seed()
        for x in xrange(0,mapsize[0]):
            for y in xrange(0,mapsize[1]):
                ''' range 0-9 '''
                if x!=0 and x!=self.mapsize[0]-1 and y!=0 and y!=self.mapsize[1]-1:
                    r = random.randint(1,100)
                    #self.gamemap[x][y] = r
                    if r <= 87:
                        self.gamemap[x][y] = random.randint(8,11)   # Stone Floor
                    elif r <=89:
                        self.gamemap[x][y] = random.randint(12,15)  # Red Floor
                    elif r <=94:
                        self.gamemap[x][y] = random.randint(16,19)  # LAVA
                    else:
                        self.gamemap[x][y] = random.randint(20,21)  # WATER
                    
                    
                else:
                    self.gamemap[x][y] = random.randint(0,7)
        #print self.gamemap
    
    def render(self,screen):
        ''' render the map '''
        a = 0
        b = 0
        for y in xrange(self.mapview[1],self.mapview[1]+self.mapview[3]):
            for x in xrange(self.mapview[0],self.mapview[0]+self.mapview[2]):
                tileindex = int(self.gamemap[x][y])
                screen.blit(self.tset.getXY(self.index[tileindex][0]),
                            (a*32,b*32))
                #print a, b
                a = a + 1
            b = b + 1
            a = 0
            #print v
    
    def mapindex(self):
        ''' generates the tile index for the map
            [0] = x,y coordinate in tileset
            [1] = tile type for walk tables etc...
        '''
        self.index = []
        for x in xrange(0,8):
            self.index.append(((x,14),0))   # Broken Dirt (8 tiles) [0...7]
        for x in xrange(17,21):
            self.index.append(((x,14),1))   # Stone Floor (4 tiles) [8...11]
        for x in xrange(21,25):
            self.index.append(((x,14),2))   # Hot Coals Floor (4 tiles) [12...15]
        for x in xrange(49,53):
            self.index.append(((x,13),3))   # LAVA Floor (4 tiles) [16..19]
        for x in xrange(5,7):
            self.index.append(((x,19),4))   # Water Floor (2 tiles) [20..21]
        for x in xrange(36,40):
            self.index.append(((x,14),5))   # Patterned Floor (4 tiles) [22...25]
        for x in xrange(40,44):
            self.index.append(((x,14),6))   # Bloody Floor (4 tiles) [26...29]
        for x in xrange(60,63):
            self.index.append(((x,12),7))   # Dirt Floor (3 tiles) [30...32]
        for x in xrange(43,47):
            self.index.append(((x,13),8))   # White Floor (4 tiles) [33...36]
    
    def getType(self,loc):
        ''' returns # of tile type at map xy '''
        tnum = int(self.gamemap[loc[0]][loc[1]])
        return self.index[tnum][1]
    
    def ppos(self,px,py):
        ''' player position event, used to determine map window '''
        
        if(px<=12):
            self.mapview[0] = 0
            self.px = px
        elif(px >= self.mapsize[0]-(self.mapview[2]/2) - 1):
            self.mapview[0] = self.mapsize[0] - self.mapview[2]
            self.px = self.mapview[2]-(self.mapsize[0]-px)
        else:
            self.mapview[0] = px-12
            self.px = 12
        
        if(py<=10):
            self.mapview[1] = 0
            self.py = py
        elif(py >= self.mapsize[1]-(self.mapview[3]/2)-1):
            self.mapview[1] = self.mapsize[1] - self.mapview[3]
            self.py = self.mapview[3]-(self.mapsize[1]-py)
        else:
            self.mapview[1] = py-10
            self.py = 10
        
        #print px, self.px, py, self.py, self.mapview[0], self.mapview[1]
    
    def isInWindow(self, loc):
        ''' Tests if a location is within the view window
            loc = [x,y] coordinate on map
        '''
        if(loc[0]>=self.mapview[0] and loc[0]<self.mapview[0]+self.mapview[2]):
            if(loc[1]>=self.mapview[1] and loc[1]<self.mapview[1]+self.mapview[3]):
                return True
        return False
    
    def getPixelXY(self,loc):
        ''' returns [x,y] pixel coordinate screen for blitting
            loc = [x,y] coordinate on map
            assumes isInWindow was called first
        '''
        x = (loc[0]-self.mapview[0])*32
        y = (loc[1]-self.mapview[1])*32
        return([x,y])
    
    def getXYfromPixel(self, loc):
        ''' returns [x,y] coordinate on map from set of pixel coordinates
            loc = [x,y] pixel coordinates
        '''
        x = (loc[0] / 32) + self.mapview[0]
        y = (loc[1] / 32) + self.mapview[1]
        return([x,y])